unit Main;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  TTapiComponent,
  StdCtrls,
  Ras3,
  Spin;

type
  TfrmMain = class(TForm)
    pnlEntries: TGroupBox;
    Label1: TLabel;
    cboPhonebook: TComboBox;
    cmdNewEntry: TButton;
    cmdEditEntry: TButton;
    cmdRenameEntry: TButton;
    cmdDeleteEntry: TButton;
    pnlCredentials: TGroupBox;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    txtUsername: TEdit;
    txtDomain: TEdit;
    txtPassword: TEdit;
    cmdGetParams: TButton;
    cmdSetParams: TButton;
    pnlActivity: TGroupBox;
    cmdDial: TButton;
    lstActivity: TListBox;
    cmdDisconnect: TButton;
    pnlSettings: TGroupBox;
    chkMinimize: TCheckBox;
    chkSyncDial: TCheckBox;
    spnRedialAttempts: TSpinEdit;
    Label5: TLabel;
    Label6: TLabel;
    spnRedialPause: TSpinEdit;
    txtPhoneNumber: TEdit;
    Label7: TLabel;
    txtCallbackNumber: TEdit;
    Label8: TLabel;
    Label9: TLabel;
    spnTimeout: TSpinEdit;
    Tapi1: TTapi;
    CheckBox1: TCheckBox;
    CheckBox2: TCheckBox;
    CheckBox3: TCheckBox;
    Button1: TButton;
    Button2: TButton;
    procedure Tapi1Connect(Sender: TObject);
    procedure Tapi1ConnectFail(Error: Longint; ErrorString: string);
    procedure Tapi1Disconnect(Error: Longint; ErrorString: string);
    procedure Tapi1Notify(Error: Longint; ErrorString: string);
    procedure cmdDialClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmdNewEntryClick(Sender: TObject);
    procedure cmdDisconnectClick(Sender: TObject);
    procedure cmdEditEntryClick(Sender: TObject);
    procedure cmdRenameEntryClick(Sender: TObject);
    procedure cmdDeleteEntryClick(Sender: TObject);
    procedure cmdGetParamsClick(Sender: TObject);
    procedure cmdSetParamsClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;
  lpbEntry: TEntry;

implementation

{$R *.DFM}
procedure TfrmMain.Tapi1Connect(Sender: TObject);
begin
  lstActivity.Items.Add('IPAddress: ' + Tapi1.IPAddress);
  lstActivity.Items.Add('ServerIPAddress: ' + Tapi1.ServerIPAddress);
  lstActivity.Items.Add('IPXAddress: ' + Tapi1.IPXAddress);
  lstActivity.Items.Add('NetBeuiAddress: ' + Tapi1.NetBeuiAddress);
  cmdDisconnect.Enabled := True;
end;

procedure TfrmMain.Tapi1ConnectFail(Error: Longint; ErrorString: string);
begin
  MessageDlg('Connection Failed!', mtError, [mbOK], 0);
  cmdDial.Enabled := true;
end;

procedure TfrmMain.Tapi1Disconnect(Error: Longint; ErrorString: string);
begin
  Tapi1.Disconnect;
  cmdDial.Enabled := true;
  cmdDisconnect.Enabled := False;
end;

procedure TfrmMain.Tapi1Notify(Error: Longint; ErrorString: string);
begin
  lstActivity.Items.Add(ErrorString + ' (' + IntToStr(Error) + ')');
  lstActivity.ItemIndex := lstActivity.Items.Count - 1;
end;

procedure TfrmMain.cmdDialClick(Sender: TObject);
begin
  With Tapi1 do
  begin
    EntryName := cboPhonebook.Text;
    Username := txtUsername.Text;
    Domain := txtDomain.Text;
    Password := txtPassword.Text;
    PhoneNumber := txtPhoneNumber.Text;
    CallbackNumber := txtCallbackNumber.Text;
    MinimizeDialWindow := chkMinimize.Checked;
    SynchronousDial := chkSyncDial.Checked;
    RedialAttempts := spnRedialAttempts.Value;
    RedialPause := spnRedialPause.Value;
    DialTimeout := spnTimeout.Value;
  end;
  Try
  begin
    Tapi1.Connect;
    cmdDial.Enabled := False;
    if (Tapi1.SynchronousDial) then
      cmdDisconnect.Enabled := True; 
  end;
  except
    on E: Exception do
      MessageDlg('An error occurred: ' + E.Message, mtError, [mbOK], 0);
  end;
end;

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  if (Tapi1.RasInitialized) then
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries)
  else
  begin
    MessageDlg('RAS could not be initialized!', mtError, [mbOK], 0);
    pnlEntries.Enabled := False;
    pnlCredentials.Enabled := False;
    pnlSettings.Enabled := False;
    pnlActivity.Enabled := False;
  end;
end;

procedure TfrmMain.cmdNewEntryClick(Sender: TObject);
begin
  if (Tapi1.CreateEntry(Self.Handle)) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to create new entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdDisconnectClick(Sender: TObject);
begin
  Tapi1.Disconnect;
  cmdDial.Enabled := true;
  cmdDisconnect.Enabled := False;
end;

procedure TfrmMain.cmdEditEntryClick(Sender: TObject);
var
  sTemp: String;
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  Tapi1.EntryName := cboPhonebook.Items[cboPhonebook.ItemIndex];

  if (Tapi1.GetEntryProperties( lpbEntry )) then
  begin
    sTemp := 'EntryName: ' + cboPhonebook.Items[cboPhonebook.ItemIndex] + #13;
    sTemp := sTemp + 'PhoneNumber: ' + lpbEntry.PhoneNumber + #13;
    sTemp := sTemp + 'DeviceName: ' + lpbEntry.DeviceName + #13;
    sTemp := sTemp + 'DeviceType: ' + lpbEntry.DeviceType + #13;
    if (lpbEntry.Proto_Netbeui) then
      sTemp := sTemp + 'NetBeui: Yes' + #13
    else
      sTemp := sTemp + 'NetBeui: No' + #13;
    if (lpbEntry.Proto_IPX) then
      sTemp := sTemp + 'IPX: Yes' + #13
    else
      sTemp := sTemp + 'IPX: No' + #13;
    if (lpbEntry.Proto_IP) then
      sTemp := sTemp + 'IP: Yes' + #13
    else
      sTemp := sTemp + 'IP: No' + #13;
    ShowMessage( sTemp );
    CheckBox1.Checked := (lpbEntry.Proto_Netbeui);
    CheckBox2.Checked := (lpbEntry.Proto_IPX);
    CheckBox3.Checked := (lpbEntry.Proto_IP);
  end
  else
    ShowMessage ('Fail');
(*
  if (Not Tapi1.EditEntry(Self.Handle, cboPhonebook.Items[cboPhonebook.ItemIndex])) then
    MessageDlg('Unable to edit new entry.', mtError, [mbOK], 0);
  *)
end;

procedure TfrmMain.cmdRenameEntryClick(Sender: TObject);
var
  NewName: String;
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  NewName := InputBox('Rename', 'Enter the new entry name:', cboPhonebook.Items[cboPhonebook.ItemIndex]);
  if (NewName = '') or (UpperCase(NewName) = UpperCase(cboPhonebook.Items[cboPhonebook.ItemIndex])) then exit;

  if (Tapi1.RenameEntry(cboPhonebook.Items[cboPhonebook.ItemIndex], NewName)) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to rename entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdDeleteEntryClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  if (MessageDlg('Are you sure you want to delete this entry?', mtConfirmation, [mbYes, mbNo], 0) = mrNo) then exit;

  if (Tapi1.DeleteEntry(cboPhonebook.Items[cboPhonebook.ItemIndex])) then
  begin
    Tapi1.GetPhonebookEntries;
    cboPhonebook.Items.Assign(Tapi1.PhonebookEntries);
  end
  else
    MessageDlg('Unable to delete entry.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdGetParamsClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  if (Tapi1.GetDialParams(cboPhonebook.Items[cboPhonebook.ItemIndex])) then
  begin
    txtUsername.Text := Tapi1.Username;
    txtPassword.Text := Tapi1.Password;
    txtDomain.Text := Tapi1.Domain;
    txtPhoneNumber.Text := Tapi1.PhoneNumber;
    txtCallbackNumber.Text := Tapi1.CallbackNumber;
  end
  else
    MessageDlg('Unable to get entry parameters.', mtError, [mbOK], 0);
end;

procedure TfrmMain.cmdSetParamsClick(Sender: TObject);
begin
  if (cboPhonebook.ItemIndex = -1) then exit;

  with Tapi1 do
  begin
    Username := txtUsername.Text;
    Password := txtPassword.Text;
    Domain := txtDomain.Text;
    PhoneNumber := txtPhoneNumber.Text;
    CallbackNumber := txtCallbackNumber.Text;
  end;
  if (Not Tapi1.SetDialParams) then
    MessageDlg('Unable to get entry parameters.', mtError, [mbOK], 0);
end;

procedure TfrmMain.Button1Click(Sender: TObject);
var
  OutStr: String;
  iter: Integer;
begin
  Tapi1.EnumConnections;
  OutStr := '';
  iter := 0;
  while (iter < Tapi1.Connections.Count) do
  begin
    OutStr := OutStr + Tapi1.Connections[iter] + #13;
    inc(iter);
  end;
  ShowMessage('Current Connections:'#13 + OutStr);
end;

procedure TfrmMain.Button2Click(Sender: TObject);
begin
  lpbEntry.Proto_NetBeui := CheckBox1.Checked;
  lpbEntry.Proto_IPX := CheckBox2.Checked;
  lpbEntry.Proto_IP := CheckBox3.Checked;
  lpbEntry.RasOptions.SpecificIPAddress := True;

  Tapi1.SetEntryProperties( lpbEntry );
end;

end.
